@@ -6,7 +6,7 @@ nett$ldv <- remove_units(nett$ldv)
 
 test_that("Vehicles works", {
   expect_equal(Vehicles(as.numeric(ef_cetesb("CO_0km", "PC_G")))[[1]],
-               0.1612112)
+               Vehicles(0.1612112))
   expect_error(Vehicles(units::set_units(1, "g")),
                  "u.?")
   expect_output(print(Vehicles(data.frame(a = 1:5, b = 1:5))),
